scqe 1 cohort, full dataThe print method provides the critical values presented in the summary
method for scqe objects.
delta.optim.scqe.1cfull(
treatment,
outcome,
delta,
obj,
specified = NULL,
alpha = 0.05,
...
)Binary or continuous vector corresponding (usually) to 0,1 (no treatment or treatment) for each observation.
Continuous vector representing the outcome for each observation.
Single value or vector of possible values for change in average non-treatment outcome between cohorts (if applicable).
scqe object.
Specified optional arguments.
Numeric alpha for confidence intervals (default alpha=.05).
Extra optional arguments.
Optimal delta.