scqe 2 cohort, full dataThe print method provides the critical values presented in the summary
method for scqe objects.
delta.optim.scqe2(
post,
treatment,
outcome,
delta,
obj,
alpha = 0.05,
specified = NULL,
...
)Binary vector corresponding to T=0,1 for each observation.
Binary or continuous vector corresponding (usually) to 0,1.
Continuous vector representing the outcome for each observation
Single value or vector of possible values for change in average non-treatment outcome between cohorts (if applicable).
scqe object.
Numeric alpha for confidence intervals (default alpha=.05).
Specified optional arguments.
Extra optional arguments.
Optimal delta.