scqe 2 cohort, summary statisticsThe print method provides the critical values presented in the summary
method for scqe objects.
delta_optim_SCQE_2C(
delta,
untr_pre,
untr_post,
tr_post,
tr_pre,
Y_tr_post,
Y_untr_post,
Y_tr_pre,
Y_untr_pre,
obj,
specified = NULL,
alpha = 0.05,
...
)Single value or vector of possible values for change in average non-treatment outcome between cohorts (if applicable).
Integer number of untreated patients in the first cohort if applicable (summary statistics input) (T=0).
Integer number of untreated patients in the second cohort if applicable (summary statistics input) (T=1).
Integer number of treated patients in the second cohort if applicable (summary statistics input) (T=1).
Integer number of treated patients in the first cohort if applicable (summary statistics input) (T=0).
Outcome for patients who received treatment at time T=1 (summary statistics input).
Outcome for patients who did not receive treatment at time T=1 (summary statistics input).
Outcome for patients who did receive treatment at time T=0 (summary statistics input).
Outcome for patients who did not receive treatment at time T=0 (summary statistics input).
scqe object.
Specified optional arguments.
Numeric alpha for confidence intervals (default alpha = 0.05).
Extra optional arguments.
Optimal delta.