powered by
This function returns the scqe estimates and confidence intervals for the 1 cohort case when the user inputs only summary statistics.
scqe.1csumm( untr_1C, Y_untr_1C, tr_1C, Y_tr_1C, delta, min_delta, max_delta, alpha = 0.05, ... )
Number of untreated individuals.
Outcome for untreated individuals.
Number of treated individuals.
Outcome for treated individuals.
Single value or vector of possible values for change in average non-treatment outcome between cohorts (if applicable).
Minimum delta. Optional, not used if delta is supplied.
delta
Maximum delta. Optional, not used if delta is supplied.
Numeric alpha for confidence interval (default is alpha = 0.05).
Extra optional arguments.
scqe object of class "scqe." Returns results table for the 1 cohort, summary statistics case.
# NOT RUN { # One cohort, summary data only scqe.1cohort.sum = scqe(untr=100,tr=200,Y_untr=5,Y_tr=50, min_delta=.1,max_delta=1) plot(scqe.1cohort.sum) summary(scqe.1cohort.sum) # }
Run the code above in your browser using DataLab